@@ -104,12 +104,17 @@ ODROID_N2 = "ODROID_N2"
 ODROID_XU4 = "ODROID_XU4"
 
 FTDI_FT232H = "FTDI_FT232H"
+FTDI_FT2232H = "FTDI_FT2232H"
 DRAGONBOARD_410C = "DRAGONBOARD_410C"
 
 SIFIVE_UNLEASHED = "SIFIVE_UNLEASHED"
 
 MICROCHIP_MCP2221 = "MICROCHIP_MCP2221"
 
+# Raspberry Pi Pico with u2if firmware
+# https://github.com/execuc/u2if
+PICO_U2IF = "PICO_U2IF"
+
 BINHO_NOVA = "BINHO_NOVA"
 
 ONION_OMEGA = "ONION_OMEGA"
