@@ -21,6 +21,7 @@ T194 = "T194"
 APQ8016 = "APQ8016"
 GENERIC_X86 = "GENERIC_X86"
 FT232H = "FT232H"
+FT2232H = "FT2232H"
 HFU540 = "HFU540"
 MCP2221 = "MCP2221"
 BINHO = "BINHO"
@@ -33,6 +34,7 @@ A33 = "A33"
 H5 = "H5"
 H616 = "H616"
 RK3308 = "RK3308"
+RK3399 = "RK3399"
 LPC4330 = "LPC4330"
 RK3288 = "RK3288"
 PENTIUM_N3710 = "PENTIUM_N3710"  # SOC Braswell core
@@ -40,5 +42,6 @@ STM32F405 = "STM32F405"
 STM32MP157 = "STM32MP157"
 MT8167 = "MT8167"
 ATOM_X5_Z8350 = "X5-Z8350"
+PICO_U2IF = "PICO_U2IF"
 
 BCM_RANGE = {"BCM2708", "BCM2709", "BCM2711", "BCM2835", "BCM2837"}
